@@ -62,15 +62,16 @@ class ConfigLoader(object):
         elif extension == ".py":
             # XXX: evaluate python script
             pass
-        elif extension == ".ini" or extension == ".cfg":
+        elif extension in (".ini", ".cfg"):
             parser = configparser.SafeConfigParser()
             parser.readfp(self.fp)
             for s in parser.sections():
                 self.config[s] = dict(parser.items(s))
-        elif extension == ".yml" or extension == ".yaml":
+        elif extension in (".yml", ".yaml"):
             if YAML_ENABLED:
                 self.config = yaml.load(self.fp)
-            logging.error("PyYAML is not installed.")
+            else:
+                logging.error("PyYAML is not installed.")
         else:
             logging.warn('Unknown file type extension: %s', extension)
 
