@@ -27,12 +27,19 @@ from clitool import (
     PROCESSING_TIME
 )
 
+warnings.simplefilter("always")
+
 if PY3:
     import csv
     import io
 
     def csvreader3(fp, encoding, **kwargs):
-        return csv.reader(io.TextIOWrapper(fp.buffer, encoding), **kwargs)
+        buf = getattr(fp, 'buffer', None)
+        if buf:
+            stream = io.TextIOWrapper(buf, encoding)
+        else:
+            stream = fp
+        return csv.reader(stream, **kwargs)
 
     csvreader = csvreader3
 
@@ -44,8 +51,6 @@ else:
 
     csvreader = csvreader2
 
-warnings.simplefilter("always")
-
 
 class SimpleDictReporter(object):
     """ Reporting class for streamer API.
@@ -101,6 +106,8 @@ class RowMapper(object):
     def __init__(self, header=None, loose=False, *args, **kwargs):
         self.header = header
         self.loose = loose
+        warnings.warn('use "clitool.textio.RowMapper" instead',
+            DeprecationWarning)
 
     def __call__(self, row, *args, **kwargs):
         """
@@ -159,11 +166,15 @@ class Streamer(object):
                     self.processes, multiprocessing.cpu_count()))
         self.reporting_interval = PROCESSING_REPORTING_INTERVAL
 
-    def consume(self, stream, chunksize=1):
+    def consume(self, stream, source=None, chunksize=1):
         """ Consuming given strem object and returns processing stats.
 
         :param stream: streaming object to consume
         :type stream: iterable
+        :param source: source of stream to consume
+        :type source: string
+        :param chunksize: chunk size for multiprocessing
+        :type chunksize: integer
         :rtype: dict
         """
         stats = {
@@ -172,6 +183,8 @@ class Streamer(object):
             PROCESSING_SUCCESS: 0,
             PROCESSING_ERROR: 0
         }
+        if source:
+            stats['source'] = source
 
         def skip_unless(r):
             if r:
@@ -219,10 +232,11 @@ class Streamer(object):
                 pool.join()
             stats[PROCESSING_TIME] = time.time() - start
             logging.info(
-                "STATS: total=%d, skipped=%d, success=%d, error=%d on %f[sec]",
+                'STATS: total=%d, skipped=%d, success=%d, error=%d on %f[sec]'
+                ' from "%s"',
                 stats[PROCESSING_TOTAL], stats[PROCESSING_SKIPPED],
                 stats[PROCESSING_SUCCESS], stats[PROCESSING_ERROR],
-                stats[PROCESSING_TIME])
+                stats[PROCESSING_TIME], stats.get('source', 'unknown'))
             return stats
 
 
@@ -232,12 +246,15 @@ class CliHandler(object):
 
     :param streamer: streaming object
     :type streamer: Streamer
+    :param delimiter: column delimiter such as "\t"
+    :type delimiter: string
     """
 
-    def __init__(self, streamer):
+    def __init__(self, streamer, delimiter=None):
         self.streamer = streamer
+        self.delimiter = delimiter
 
-    def reader(self, fp, encoding=None):
+    def reader(self, fp, encoding):
         """ Simple `open` wrapper for several file types.
         This supports ``.gz`` and ``.json``.
 
@@ -253,6 +270,10 @@ class CliHandler(object):
             return gzip.open(fp.name)
         elif suffix == '.json':
             return json.load(fp)
+        elif suffix == '.csv' or self.delimiter:
+            return csvreader(fp, encoding, delimiter=self.delimiter or ',')
+        elif suffix == '.tsv':
+            return csvreader(fp, encoding, delimiter='\t')
         return fp
 
     def handle(self, files, encoding, chunksize=1):
@@ -270,18 +291,17 @@ class CliHandler(object):
         if files:
             logging.info("Input file count: %d", len(files))
             for fp in files:
-                fname = fp.name
-                logging.info("Start processing: %s", fname)
-                reader = self.reader(fp, encoding)
-                parsed = self.streamer.consume(reader, chunksize)
-                logging.info("End processing: %s", fname)
-                parsed['file'] = fname
+                stream = self.reader(fp, encoding)
+                parsed = self.streamer.consume(stream,
+                    source=fp.name, chunksize=chunksize)
                 stats.append(parsed)
                 if not fp.closed:
                     fp.close()
         else:
-            reader = self.reader(sys.stdin, encoding)
-            parsed = self.streamer.consume(reader)
+            stream = sys.stdin
+            if self.delimiter:
+                stream = csvreader(stream, encoding, delimiter=self.delimiter)
+            parsed = self.streamer.consume(stream, chunksize=chunksize)
             stats.append(parsed)
         return stats
 
@@ -289,12 +309,9 @@ class CliHandler(object):
 class CsvHandler(CliHandler):
 
     def reader(self, fp, encoding):
+        warnings.warn('use "CliHandler()" with "delimiter" option instead',
+            DeprecationWarning)
         return csvreader(fp, encoding)
 
 
-def clistream(reporter, *args, **kwargs):
-    warnings.warn("use 'clitool.cli.clistream' instead.", DeprecationWarning)
-    from .cli import clistream as new_clistream
-    return new_clistream(reporter, *args, **kwargs)
-
 # vim: set et ts=4 sw=4 cindent fileencoding=utf-8 :
